==> archive-Bate-1.0.0-sources.jar: com/gtis/archive/Switch.java <==
package com.gtis.archive;

/**
 * 档案系统功能开关.
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 * @version V1.0, 11-12-20
 */
public class Switch {
    public static final String ORIGINAL_PERMISSION = "originalPermission.enable";
    public static final String DWDM = "dwdm.enable";
    public static final String ARCHIVE3D = "archive3d.enable";
    public static final String XIAN = "xian.enable";
    public static final String JIANGYIN = "jiangyin.enable";
    public static final String JURONG = "jurong.enable";
    public static final String ALLOW_NULL_DH = "allowNullDh.enable";
    public static final String BENG_BU = "bengbu.enable";
    public static final String JIN_TAN = "jintan.enable";
    public static final String LIAN_YUNGANG = "lianyungang.enable";
    public static final String SIHONG = "sihong.enable";
    public static final String AUTO_IDENTIFY_ORIGINAL = "autoIdentifyOriginal.enable";
    public static final String INDIVIDUAL_MLH = "individualMlh.enable";
    public static final String INCREASE_AJH = "increaseAjh.enable";
    public static final String CHANGZHOU = "changzhou.enable";
    public static final String CLASSIFYVIEWMODE = "classifyViewMode";
    public static final String NOT_CHECK_AJH = "notCheckAjh.enable";
    public static final String ORHINAL_OWNER_PATH = "orignalOwnerPath.enable";
    public static final String WGDYW = "wgdyw.enable";
    public static final String IMPORTEXCEL = "importExcel.enable";
    public static final String SJWS = "sjws.enable";
    public static final String TDDJPATH = "tddj.path";
    public static final String LIYANG = "liyang.enable";
    public static final String GUIDANG = "guidang.enable";
    public static final String DONGTAI = "dongtai.enable";
    public static final String NOT_NEED_AJH = "notNeedAjh.enable";
    public static final String VIEWMANAGE = "viewManage.enable";
    public static final String ZHEN_JINAG = "zhenjiang.enable";
    public static final String AUTO_CREATE_AJH = "autoCreateAjh.enable";
    public static final String AUTO_CREATE_CABINETSNO = "autoCreateCabinetsno.enable";
    public static final String SPLIT_QUERY = "splitQuery.enable";
    public static final String HASGDR_GDRID = "hasGdR.GdrId";
    public static final String HASLRR_LRRID = "hasLrr.GdrId";
    public static final String IS_PRINT_DOC_PACKAGE = "isPrintDocPackage";
    public static final String CREATEDHBYMODELNAME = "createDhByModelName";
    public static final String DOCUMENT_PRINT_COUNT = "document.print.count";
}

==> archive-Bate-1.0.2-sources.jar: com/gtis/archive/Switch.java <==
package com.gtis.archive;

/**
 * 档案系统功能开关.
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 * @version V1.0, 11-12-20
 */
public class Switch {
    public static final String ORIGINAL_PERMISSION = "originalPermission.enable";
    public static final String DWDM = "dwdm.enable";
    public static final String  ORAGAN_NO = "oraganNo.enable";
    public static final String ARCHIVE3D = "archive3d.enable";
    public static final String XIAN = "xian.enable";
    public static final String JIANGYIN = "jiangyin.enable";
    public static final String JURONG = "jurong.enable";
    public static final String ALLOW_NULL_DH = "allowNullDh.enable";
    public static final String BENG_BU = "bengbu.enable";
    public static final String JIN_TAN = "jintan.enable";
    public static final String LIAN_YUNGANG = "lianyungang.enable";
    public static final String SIHONG = "sihong.enable";
    public static final String AUTO_IDENTIFY_ORIGINAL = "autoIdentifyOriginal.enable";
    public static final String INDIVIDUAL_MLH = "individualMlh.enable";
    public static final String INCREASE_AJH = "increaseAjh.enable";
    public static final String CHANGZHOU = "changzhou.enable";
    public static final String CLASSIFYVIEWMODE = "classifyViewMode";
    public static final String NOT_CHECK_AJH = "notCheckAjh.enable";
    public static final String ORHINAL_OWNER_PATH = "orignalOwnerPath.enable";
    public static final String WGDYW = "wgdyw.enable";
    public static final String IMPORTEXCEL = "importExcel.enable";
    public static final String SJWS = "sjws.enable";
    public static final String TDDJPATH = "tddj.path";
    public static final String LIYANG = "liyang.enable";
    public static final String GUIDANG = "guidang.enable";
    public static final String DONGTAI = "dongtai.enable";
    public static final String NOT_NEED_AJH = "notNeedAjh.enable";
    public static final String ZHEN_JINAG = "zhenjiang.enable";
    public static final String AUTO_CREATE_AJH = "autoCreateAjh.enable";
    public static final String AUTO_CREATE_CABINETSNO = "autoCreateCabinetsno.enable";
    public static final String SPLIT_QUERY = "splitQuery.enable";
    public static final String HASGDR_GDRID = "hasGdR.GdrId";
    public static final String HASLRR_LRRID = "hasLrr.GdrId";
    public static final String IS_PRINT_DOC_PACKAGE = "isPrintDocPackage";
    public static final String CREATEDHBYMODELNAME = "createDhByModelName";
    public static final String DOCUMENT_PRINT_COUNT = "document.print.count";
    public static final String ISALLOWNEWDH = "isAllowNewDh";
    public static final String RETURNARCHIVEURL = "returnArchiveUrl";
    public static final String RECORD_AJH_RANGE = "recordAjhRange.enable";
    public static final String QRCODE_FIELD_NAME = "qrCode.Field.Name";
}
